@@ -52,7 +52,11 @@ SpeakerSettings speakers[]=
     {"location",	DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"message",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"name",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
+    {"description",	DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"role",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
+    {"column_header",	DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
+    {"row_header",	DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
+    {"cell",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"shortcut",	DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"state",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
     {"system",		DEFAULT_SPEECH_ENGINE_DRIVER, NULL, DEFAULT_SPEECH_ENGINE_VOICE, NULL,	DEFAULT_SPEECH_VOLUME,	DEFAULT_SPEECH_RATE,	DEFAULT_SPEECH_PITCH},
@@ -63,6 +67,12 @@ SpeakerSettings speakers[]=
 extern GConfClient *gnopernicus_client;
 DictionaryListType *dictionary_list = NULL;
 
+gboolean 
+spconf_key_is_valid (gchar *path)
+{
+    return gconf_valid_key (path, NULL);
+}
+
 /**
  *
  * Create a new gconf client for Speech settings
@@ -786,6 +796,44 @@ spconf_driver_list_get_driver_name_descr (SpeechDriverListType *driver_list,
     return NULL;
 }
 
+const gchar*
+spconf_voice_list_get_default_voice (GSList *voices, 
+				     gchar *voice_name)
+{
+    GSList *tmp;
+    
+    for (tmp = voices; tmp; tmp = tmp->next)
+    {
+	SpeechVoice *speech_voice = (SpeechVoice *)tmp->data;
+	if (!strcmp (speech_voice->voice_name, voice_name))
+	    return speech_voice->voice_name_descr;
+    }
+
+    return (((SpeechVoice *) voices->data)->voice_name_descr);
+}
+
+const SpeechDriver*
+spconf_driver_list_get_default_driver (SpeechDriverListType *driver_list,
+				       const gchar *driver_name)
+{
+    SpeechDriverListType *tmp;
+    
+    if (!driver_list)
+	return NULL;
+    if (!driver_name)
+	return NULL;
+
+    for (tmp = driver_list ; tmp ; tmp = tmp->next)
+    {
+	SpeechDriver *driver = (SpeechDriver *)tmp->data;
+
+	if (!strcmp (driver->driver_name, driver_name))
+	    return driver;
+    }
+    
+    return ((SpeechDriver *) driver_list->data);
+}
+
 /**
  * spconf_driver_list_get_driver_from_name_descr:
  *
