@@ -551,7 +551,7 @@ srs_sp_clb (gpointer 	   id,
 }
 
 gboolean
-srs_sp_init (SRSMarkersCallback callback)
+srs_sp_init (SRSMarkersCallback callback, SRSResetCallback reset_callback)
 {
     sru_assert (callback);
 
@@ -566,7 +566,7 @@ srs_sp_init (SRSMarkersCallback callback)
     srs_voices = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
 			(GDestroyNotify)srs_voice_terminate);
 
-    return srs_gs_init (srs_sp_clb);
+    return srs_gs_init (srs_sp_clb, reset_callback);
 }
 
 void
