@@ -31,7 +31,7 @@ main ()
 	int len;
 	char* buff;
 	
-	srs_init (NULL);
+	srs_init (NULL, NULL);
 	
 	fp = fopen ("srsml.xml", "rt");
 	
