@@ -38,12 +38,14 @@
 #include "srintl.h"
 #include "screen-review.h"
 #include <libxml/parser.h>
+#include "sru-debug.h"
 
 /* mouse motion idle support */
 #define SRC_MOUSE_MOVED_TIMEOUT		300 /* ms */
 static gboolean src_mouse_is_moving = FALSE;
 static guint mouse_stopped_moving_timeout_handler = 0;
 static guint mouse_is_moving_idle_handler = 0;
+static gint context_switched = 0;
 
 gboolean login_time;
 
@@ -268,6 +270,9 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	    sro_get_role (obj, &role, SR_INDEX_CONTAINER);
 	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0)
 	    {
+		if (context_switched == 1)
+		    src_speech_shutup ();
+		context_switched++;
 		if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
 		else if ((role == SR_ROLE_TABLE || role == SR_ROLE_TREE_TABLE) &&
@@ -275,10 +280,10 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, FALSE);
 		else
 		{
-		    gboolean interrupt = TRUE;
 		    if (strcmp (reason, "object:text-changed:insert") == 0 && role == SR_ROLE_TERMINAL)
-			interrupt = FALSE;
-		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, interrupt);
+			src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, FALSE);
+		    else
+			src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, TRUE);
 		}
 	    }
 	    else if (srl_is_object_watched (obj))
@@ -401,7 +406,10 @@ src_present_crt_window ()
 	    else if (strcmp (reason, "window:rename") == 0)
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, TRUE);
 	    else if (strcmp (reason, "object:context-switched") == 0)
+	    {
+		context_switched = 0;
 	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
+	    }
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
 	}
@@ -2322,6 +2330,20 @@ src_set_command_lines (const gchar *mouse_tracking,
     }
 }    
 
+static gboolean
+src_login_focus (gpointer data)
+{
+    SRObject *focus;
+
+    focus = srl_get_focus_object ();
+    if (focus)
+    {
+	src_process_sro (focus);
+	sro_release_reference (focus);
+    }
+    return FALSE;
+}
+
 static void
 src_init(const gchar *mouse_tracking,
 	 const gchar *focus_tracking,
@@ -2336,6 +2358,8 @@ src_init(const gchar *mouse_tracking,
     gboolean initialize_finished = FALSE;
     gboolean default_invert_value;
 
+    sru_debug_init ();
+
     /* initialize SR Utils */
     sru_init();
 
@@ -2435,6 +2459,8 @@ src_init(const gchar *mouse_tracking,
     src_last_space_echo 	= NULL;
     src_last_modifier_echo 	= NULL;
     src_last_cursor_echo 	= NULL;
+    context_switched 		= 0;
+
     if (brl_error)
 	src_say_message (_("braille device can not be initialized"));
 
@@ -2442,6 +2468,8 @@ src_init(const gchar *mouse_tracking,
     SET_SRCORE_CONFIG_DATA(SRCORE_INITIALIZATION_END, CFGT_BOOL, &initialize_finished);
     initialize_finished = !initialize_finished;
     SET_SRCORE_CONFIG_DATA(SRCORE_INITIALIZATION_END, CFGT_BOOL, &initialize_finished);    
+    if (login_time)
+	g_idle_add (src_login_focus, NULL);
 }
 
 static void
@@ -2520,6 +2548,8 @@ src_terminate()
 	g_free (src_last_modifier_echo);
     if (src_last_cursor_echo)
 	g_free (src_last_cursor_echo);
+
+    sru_debug_terminate ();
 }
     
 gint
