@@ -23,7 +23,7 @@
 #define __SRINTL_H__
 
 #include "config.h"
-#include "libgnome/libgnome.h"
+#include "glib/gi18n.h"
 
 #ifndef ENABLE_NLS
 #define ngettext(x, y, z) ((z) == 1 ? (x) : (y))
